==> emodpy_tbhiv-0.0.6-py3-none-any.whl: tests/test_hivseed.py <==
#!/usr/bin/env python
import os
import unittest
import copy
import json
from intervention_test import TestIntervention
import manifest

import emodpy_tbhiv.interventions.hiv_seeding as hs
import emod_api.campaign as camp

current_directory = os.path.dirname(os.path.realpath(__file__))


class Testhivseed(TestIntervention):
    """
    Test GroupInterventionDistributionEventCoordinatorHIV intervention
    """
    def test_default(self):
        camp.schema_path = self.schema
        time_offset = 44
        event = hs.HIV(camp, time_offset)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_hivseed.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        self.assertEqual(ecc['Time_Offset'], time_offset)

    def test_all(self):
        camp.schema_path = self.schema
        time_offset = 7
        reps = 2
        interval = 3
        start_day = 4
        nodeIDs = []
        event_name = 'HIV Incidence'
        event = hs.HIV(camp, time_offset, reps, interval, start_day, nodeIDs,event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_hivseed.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic['class'], 'OutbreakIndividualTBorHIV')
        self.assertEqual(ic['Infection_Type'], 'HIV')
        self.assertEqual(ecc['Time_Offset'], time_offset)
        self.assertEqual(ecc['Timesteps_Between_Repetitions'], interval)
        self.assertEqual(ecc['Number_Repetitions'], reps)


if __name__ == '__main__':
    unittest.main()

==> emodpy_tbhiv-0.0.13-py3-none-any.whl: tests/test_hivseed.py <==
#!/usr/bin/env python
import os
import unittest
import copy
import json
from intervention_test import TestIntervention
import manifest

import emodpy_tbhiv.interventions.hiv_seeding as hs
import emod_api.campaign as camp

current_directory = os.path.dirname(os.path.realpath(__file__))


class Testhivseed(TestIntervention):
    """
    Test GroupInterventionDistributionEventCoordinatorHIV intervention
    """
    def test_default(self):
        camp.schema_path = self.schema
        time_offset = 44
        event = hs.HIV(camp, time_offset)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_hivseed.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        self.assertEqual(ecc['Time_Offset'], time_offset)

    def test_all(self):
        camp.schema_path = self.schema
        time_offset = 7
        reps = 2
        interval = 3
        start_day = 4
        nodeIDs = []
        event_name = 'HIV Incidence'
        event = hs.HIV(camp=camp, time_offset=time_offset, disease='HIV',
                       reps=reps, interval=interval, start_day=start_day, nodeIDs=nodeIDs, event_name=event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_hivseed.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic['class'], 'OutbreakIndividualTBorHIV')
        self.assertEqual(ic['Infection_Type'], 'HIV')
        self.assertEqual(ecc['Time_Offset'], time_offset)
        self.assertEqual(ecc['Timesteps_Between_Repetitions'], interval)
        self.assertEqual(ecc['Number_Repetitions'], reps)

    def test_new_intervention_as_file(self, intervention_class_name='OutbreakIndividualTBorHIV'):
        camp_filename = os.path.join(self.output, 'camp_hivseed_as_file.json')

        hs.new_intervention_as_file(camp, filename=camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(ic["class"], intervention_class_name)


if __name__ == '__main__':
    unittest.main()
